<div align = "center">
    <img src="./docs/media/Logo.png" width = "111" height = "111" alt="Logo">

# PyEasyUtils

A simple utility library for python.

[![PyPI](https://img.shields.io/pypi/v/PyEasyUtils?color=blue&logo=PYPY&logoColor=blue&style=for-the-badge)](https://pypi.org/project/PyEasyUtils/)&nbsp;

[**简体中文**](./docs/README_CN.md) | **English**

</div>

---

## Deployment

### pip

```shell
pip install PyEasyUtils -i https://pypi.org/simple/
```


## Cases
Here are some projects based on PyEasyUtils:
- [QEasyWidgets](https://github.com/Spr-Aachen/QEasyWidgets)
- [Easy Voice Toolkit](https://github.com/Spr-Aachen/Easy-Voice-Toolkit)
- [Android Screen Defects Detector](https://github.com/Spr-Aachen/Android-Screen-Defects-Detector.git)
- [LLM PromptMaster](https://github.com/Spr-Aachen/LLM-PromptMaster)